==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeOrFilteringExpressionDescription } from "./WebFilteringExpressionsTreeOrFilteringExpressionDescription";
/**
 * @hidden
 */
export let WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a == null) {
                WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.c(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a);
            }
            if (a.j(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a)) {
                return;
            }
            a.y(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringExpressionsTreeOrFilteringExpression");
        }
        static d(a) {
            WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.b(a);
            a.aa("WebFilteringExpressionsTreeOrFilteringExpression", () => new WebFilteringExpressionsTreeOrFilteringExpressionDescription());
            a.z("WebFilteringExpressionsTreeOrFilteringExpression", WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a);
        }
    }
    WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata, 'WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata');
    WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a = null;
    return WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeOrFilteringExpressionDescription } from "./WebFilteringExpressionsTreeOrFilteringExpressionDescription";
/**
 * @hidden
 */
export let WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a == null) {
                WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.c(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a);
            }
            if (a.k(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringExpressionsTreeOrFilteringExpression");
        }
        static d(a) {
            WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.b(a);
            a.ac("WebFilteringExpressionsTreeOrFilteringExpression", () => new WebFilteringExpressionsTreeOrFilteringExpressionDescription());
            a.ab("WebFilteringExpressionsTreeOrFilteringExpression", WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a);
        }
    }
    WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata, 'WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata');
    WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.a = null;
    return WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata;
})();
